==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemə qayıdılır, lütfən gözləyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Geri qayıtma baş tutmadı.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başladın</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Yenilənmə baş tutmadı.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Yenilənmə baş tutmadı: yarımçıq kəsildi.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Yenilənmə baş tutmadı: DPKG xətası.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Yenilənmə baş tutmadı: diskdə boş sahə azdır.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2-də/da yedəklənmiş %1-ə/a qayıtmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Ləğv edin və yenidən başladın</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Təsdiq edin</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_az.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemə qayıdılır, lütfən gözləyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Geri qayıtma baş tutmadı.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başladın</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Yenilənmə baş tutmadı.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Yenilənmə baş tutmadı: yarımçıq kəsildi.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Yenilənmə baş tutmadı: DPKG xətası.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Yenilənmə baş tutmadı: diskdə boş sahə azdır.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2-də/da yedəklənmiş %1-ə/a qayıtmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Ləğv edin və yenidən başladın</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Təsdiq edin</translation>
    </message>
</context>
</TS>
